bumpversion
===========

Commit the bumping of the version.py file

| This simple script searches for a single version.py file in the
  current directory and subdirectories and commits its changes,
  including the new version number in the commit message.
| When multiple version.py files are found the script will throw an
  error and do nothing.
